==> ovirt-engine-sdk-java-4.1.1.tar.gz: ovirt-engine-sdk-java-4.1.1/target/generated-sources/org/ovirt/engine/sdk4/services/ClusterLevelsService.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import java.util.List;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.types.ClusterLevel;

/**
 * Provides information about the capabilities of different cluster levels supported by the engine. Version 4.0 of the
 * engine supports levels 4.0 and 3.6. Each of these levels support different sets of CPU types, for example. This
 * service provides that information.
 */
public interface ClusterLevelsService extends Service {
    /**
     * Lists the cluster levels supported by the system.
     * 
     * [source]
     * ----
     * GET /ovirt-engine/api/clusterlevels
     * ----
     * 
     * This will return a list of available cluster levels.
     * 
     * [source,xml]
     * ----
     * <cluster_levels>
     *   <cluster_level id="4.0">
     *      ...
     *   </cluster_level>
     *   ...
     * </cluster_levels>
     * ----
     */
    public interface ListRequest extends Request<ListRequest, ListResponse> {
    }
    
    /**
     * Lists the cluster levels supported by the system.
     * 
     * [source]
     * ----
     * GET /ovirt-engine/api/clusterlevels
     * ----
     * 
     * This will return a list of available cluster levels.
     * 
     * [source,xml]
     * ----
     * <cluster_levels>
     *   <cluster_level id="4.0">
     *      ...
     *   </cluster_level>
     *   ...
     * </cluster_levels>
     * ----
     */
    public interface ListResponse extends Response {
        /**
         * Retrieved cluster levels.
         */
        List<ClusterLevel> levels();
    }
    
    /**
     * Lists the cluster levels supported by the system.
     * 
     * [source]
     * ----
     * GET /ovirt-engine/api/clusterlevels
     * ----
     * 
     * This will return a list of available cluster levels.
     * 
     * [source,xml]
     * ----
     * <cluster_levels>
     *   <cluster_level id="4.0">
     *      ...
     *   </cluster_level>
     *   ...
     * </cluster_levels>
     * ----
     */
    ListRequest list();
    
    /**
     * Reference to the service that provides information about an specific cluster level.
     */
    ClusterLevelService levelService(String id);
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}

==> ovirt-engine-sdk-java-4.1.4.tar.gz: ovirt-engine-sdk-java-4.1.4/target/generated-sources/org/ovirt/engine/sdk4/services/ClusterLevelsService.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import java.util.List;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.types.ClusterLevel;

/**
 * Provides information about the capabilities of different cluster levels supported by the engine. Version 4.0 of the
 * engine supports levels 4.0 and 3.6. Each of these levels support different sets of CPU types, for example. This
 * service provides that information.
 */
public interface ClusterLevelsService extends Service {
    /**
     * Lists the cluster levels supported by the system.
     * 
     * [source]
     * ----
     * GET /ovirt-engine/api/clusterlevels
     * ----
     * 
     * This will return a list of available cluster levels.
     * 
     * [source,xml]
     * ----
     * <cluster_levels>
     *   <cluster_level id="4.0">
     *      ...
     *   </cluster_level>
     *   ...
     * </cluster_levels>
     * ----
     * 
     * The order of the returned cluster levels isn't guaranteed.
     */
    public interface ListRequest extends Request<ListRequest, ListResponse> {
    }
    
    /**
     * Lists the cluster levels supported by the system.
     * 
     * [source]
     * ----
     * GET /ovirt-engine/api/clusterlevels
     * ----
     * 
     * This will return a list of available cluster levels.
     * 
     * [source,xml]
     * ----
     * <cluster_levels>
     *   <cluster_level id="4.0">
     *      ...
     *   </cluster_level>
     *   ...
     * </cluster_levels>
     * ----
     * 
     * The order of the returned cluster levels isn't guaranteed.
     */
    public interface ListResponse extends Response {
        /**
         * Retrieved cluster levels.
         */
        List<ClusterLevel> levels();
    }
    
    /**
     * Lists the cluster levels supported by the system.
     * 
     * [source]
     * ----
     * GET /ovirt-engine/api/clusterlevels
     * ----
     * 
     * This will return a list of available cluster levels.
     * 
     * [source,xml]
     * ----
     * <cluster_levels>
     *   <cluster_level id="4.0">
     *      ...
     *   </cluster_level>
     *   ...
     * </cluster_levels>
     * ----
     * 
     * The order of the returned cluster levels isn't guaranteed.
     */
    ListRequest list();
    
    /**
     * Reference to the service that provides information about an specific cluster level.
     */
    ClusterLevelService levelService(String id);
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}
